@@ -1,7 +1,7 @@
 /*
  * DSI utilities
  *
- * Copyright (C) 2002-2022 Sebastiano Vigna
+ * Copyright (C) 2002-2023 Sebastiano Vigna
  *
  * This program and the accompanying materials are made available under the
  * terms of the GNU Lesser General Public License v2.1 or later,
@@ -30,6 +30,7 @@ import java.nio.charset.StandardCharsets;
 import java.util.Iterator;
 import java.util.RandomAccess;
 
+import it.unimi.dsi.lang.FlyweightPrototype;
 import org.apache.commons.configuration2.ex.ConfigurationException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -85,7 +86,7 @@ import it.unimi.dsi.util.Properties;
  * @see FrontCodedStringBigList
  */
 
-public class MappedFrontCodedStringBigList extends AbstractObjectBigList<MutableString> implements RandomAccess, Closeable {
+public class MappedFrontCodedStringBigList extends AbstractObjectBigList<MutableString> implements RandomAccess, Closeable, FlyweightPrototype<MappedFrontCodedStringBigList> {
 	public static final long serialVersionUID = 1;
 	public static final String PROPERTIES_EXTENSION = ".properties";
 	public static final String BYTE_ARRAY_EXTENSION = ".bytearray";
@@ -117,6 +118,25 @@ public class MappedFrontCodedStringBigList extends AbstractObjectBigList<Mutable
 		this.byteList = ByteMappedBigList.map(fileChannel);
 	}
 
+	private MappedFrontCodedStringBigList(final long n, final int ratio, final ByteBigList byteList, final LongBigList pointers, final FileChannel fileChannel) {
+		this.n = n;
+		this.ratio = ratio;
+		this.byteList = byteList;
+		this.pointers = pointers;
+		this.fileChannel = fileChannel;
+	}
+
+	@Override
+	public MappedFrontCodedStringBigList copy() {
+		return new MappedFrontCodedStringBigList(
+				n,
+				ratio,
+				(byteList instanceof ByteMappedBigList) ? ((ByteMappedBigList) byteList).copy() : byteList,
+				(pointers instanceof LongMappedBigList) ? ((LongMappedBigList) pointers).copy() : pointers,
+				fileChannel
+		);
+	}
+
 	/**
 	 * Writes a length.
 	 *
