@@ -1,7 +1,7 @@
 /*
  * DSI utilities
  *
- * Copyright (C) 2015-2022 Sebastiano Vigna
+ * Copyright (C) 2015-2023 Sebastiano Vigna
  *
  * This program and the accompanying materials are made available under the
  * terms of the GNU Lesser General Public License v2.1 or later,
@@ -27,7 +27,6 @@ import org.apache.commons.math3.random.RandomGenerator;
 
 import it.unimi.dsi.Util;
 import it.unimi.dsi.fastutil.HashCommon;
-import it.unimi.dsi.logging.ProgressLogger;
 
 /** A fast, high-quality, non-splittable version of the <span style="font-variant: small-caps">SplitMix</span>
  * pseudorandom number generator used by {@link SplittableRandom}. Due to
@@ -159,18 +158,4 @@ public class SplitMix64RandomGenerator extends AbstractRandomGenerator implement
 	public void setState(final long state) {
 		x = state;
 	}
-
-	public static void main(final String[] arg) {
-		final long n = Long.parseLong(arg[0]);
-		long x = 0;
-		final ProgressLogger pl = new ProgressLogger();
-		final SplitMix64RandomGenerator r = new SplitMix64RandomGenerator();
-		for(int k = 10; k-- != 0;) {
-			pl.start("Measuring...");
-			for (long i = n; i-- != 0;)
-				x ^= r.nextLong();
-			pl.done(n);
-			if (x == 0) System.out.println(x);
-		}
-	}
 }
