@@ -1,7 +1,7 @@
 /*
  * DSI utilities
  *
- * Copyright (C) 2013-2022 Sebastiano Vigna
+ * Copyright (C) 2013-2023 Sebastiano Vigna
  *
  * This program and the accompanying materials are made available under the
  * terms of the GNU Lesser General Public License v2.1 or later,
@@ -27,7 +27,6 @@ import org.apache.commons.math3.random.AbstractRandomGenerator;
 import org.apache.commons.math3.random.RandomGenerator;
 
 import it.unimi.dsi.Util;
-import it.unimi.dsi.logging.ProgressLogger;
 
 /**
  * A fast, all-purpose, rock-solid {@linkplain RandomGenerator pseudorandom number generator}. It
@@ -357,18 +356,4 @@ public class XoShiRo256PlusPlusRandomGenerator extends AbstractRandomGenerator i
 		s2 = state[2];
 		s3 = state[3];
 	}
-
-	public static void main(final String[] arg) {
-		final long n = Long.parseLong(arg[0]);
-		long x = 0;
-		final ProgressLogger pl = new ProgressLogger();
-		final XoShiRo256PlusPlusRandomGenerator r = new XoShiRo256PlusPlusRandomGenerator(0);
-		for(int k = 10; k-- != 0;) {
-			pl.start("Measuring...");
-			for (long i = n; i-- != 0;)
-				x ^= r.nextLong();
-			pl.done(n);
-			if (x == 0) System.out.println(x);
-		}
-	}
 }
